@@ -7,7 +7,6 @@ import pandas as pd
 import seaborn as sns
 from statannot import add_stat_annotation
 
-from biopsykit.utils.dataframe_handling import multi_xs
 from biopsykit.utils.functions import se
 
 _PVALUE_THRESHOLDS = [[1e-3, "***"], [1e-2, "**"], [0.05, "*"]]
@@ -393,7 +392,6 @@ def _feature_boxplot_sanitize_stats_kwargs(stats_kwargs: Dict[str, Any]) -> Dict
     return stats_kwargs
 
 
-# TODO "group" parameter should always be "x"? check if "group" can be omitted
 def multi_feature_boxplot(  # pylint:disable=too-many-branches
     data: pd.DataFrame,
     x: str,
@@ -488,7 +486,7 @@ def multi_feature_boxplot(  # pylint:disable=too-many-branches
     rect = kwargs.pop("rect", (0, 0, 0.825, 1.0) if legend_orientation == "vertical" else (0, 0, 1, 0.925))
 
     if isinstance(features, list):
-        features = {f: f for f in features}
+        features = {f: [f] if isinstance(f, str) else f for f in features}
 
     axs: List[plt.Axes] = kwargs.pop("axs", kwargs.pop("ax", None))
     fig, axs = _plot_get_fig_ax_list(features, axs, **kwargs)
@@ -502,9 +500,9 @@ def multi_feature_boxplot(  # pylint:disable=too-many-branches
     handles = None
     labels = None
     for ax, key in zip(axs, features):
-        data_plot = multi_xs(data, features[key], level=group)
+        data_plot = data.reindex(features[key], level=group)
         if data_plot.empty:
-            raise ValueError("Empty dataframe for '{}'!".format(key))
+            raise ValueError(f"Empty dataframe for '{key}'!")
 
         order_list = _multi_feature_boxplot_get_order(order, key)
 
@@ -550,6 +548,50 @@ def _multi_feature_boxplot_get_order(order: Union[Dict[str, Sequence[str]], Sequ
     return order
 
 
+def feature_pairplot(
+    data: pd.DataFrame, abbreviate_names: Optional[bool] = True, **kwargs
+) -> Union[sns.PairGrid, Tuple[sns.PairGrid, pd.DataFrame]]:
+    """Plot feature pairs of a dataset.
+
+    This function provides a convenient interface to the :func:`~seaborn.pairplot` class, with several additional
+    features, such as showing abbreviated feature names in the plot with a description below the plot.
+
+    Parameters
+    ----------
+    data : :class:`~pandas.DataFrame`
+        DataFrame with feature data to plot. Data is expected to be in wide format.
+    abbreviate_names : bool, optional
+        if ``True``, feature names are abbreviated in the plot and a description is shown below the plot.
+    **kwargs
+        additional keyword arguments are passed down to :func:`~seaborn.pairplot`
+
+    Returns
+    -------
+    :class:`~seaborn.FacetGrid`
+        :class:`~seaborn.FacetGrid` object with the pairplot in it.
+
+    See Also
+    --------
+    :class:`~seaborn.pairplot`
+        seaborn class to create pairplots
+
+    """
+    if abbreviate_names:
+        data = data.copy()
+        feature_names = data.columns
+        # assign numbers to column names
+        data.columns = range(len(data.columns))
+        data.columns = data.columns.astype(str)
+        data = data.add_prefix("feature #")
+
+        # dataframe with assignment of column names to numbers
+        feature_names_df = pd.DataFrame(feature_names, columns=["feature_name"])
+        feature_names_df.index.name = "feature_id"
+        return sns.pairplot(data=data.reset_index(), **kwargs), feature_names_df
+
+    return sns.pairplot(data=data.reset_index(), **kwargs)
+
+
 def _get_df_lineplot(data: pd.DataFrame, x: str, y: str, hue: str, order: Sequence[str]) -> pd.DataFrame:
     if "mean" in data.columns and "se" in data.columns:
         m_se = data
